@@ -1,4 +1,4 @@
-/*	$NetBSD: schizo.c,v 1.35 2015/11/27 09:34:36 martin Exp $	*/
+/*	$NetBSD: schizo.c,v 1.36 2016/05/10 19:23:59 palle Exp $	*/
 /*	$OpenBSD: schizo.c,v 1.55 2008/08/18 20:29:37 brad Exp $	*/
 
 /*
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: schizo.c,v 1.35 2015/11/27 09:34:36 martin Exp $");
+__KERNEL_RCSID(0, "$NetBSD: schizo.c,v 1.36 2016/05/10 19:23:59 palle Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
