@@ -1,4 +1,4 @@
-/*	$NetBSD: ipifuncs.c,v 1.55 2015/01/04 15:24:18 palle Exp $ */
+/*	$NetBSD: ipifuncs.c,v 1.56 2016/01/30 22:47:06 palle Exp $ */
 
 /*-
  * Copyright (c) 2004 The NetBSD Foundation, Inc.
@@ -27,7 +27,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ipifuncs.c,v 1.55 2015/01/04 15:24:18 palle Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ipifuncs.c,v 1.56 2016/01/30 22:47:06 palle Exp $");
 
 #include "opt_ddb.h"
 
@@ -212,13 +212,16 @@ sparc64_multicast_ipi(sparc64_cpuset_t cpuset, ipifunc_t func, uint64_t arg1,
 		      uint64_t arg2)
 {
 	struct cpu_info *ci;
+/*printf("%s\n", __FUNCTION__);*/
 
 	CPUSET_DEL(cpuset, cpu_number());
-	if (CPUSET_EMPTY(cpuset))
+	if (CPUSET_EMPTY(cpuset)) {
+	  /*printf("%s empty \n", __FUNCTION__);*/
 		return;
-
+	}
 	for (ci = cpus; ci != NULL; ci = ci->ci_next) {
 		if (CPUSET_HAS(cpuset, ci->ci_index)) {
+		  printf("%s not empty \n", __FUNCTION__);
 			CPUSET_DEL(cpuset, ci->ci_index);
 			sparc64_send_ipi(ci->ci_cpuid, func, arg1, arg2);
 		}
@@ -245,6 +248,7 @@ sparc64_send_ipi_sun4u(int upaid, ipifunc_t func, uint64_t arg1, uint64_t arg2)
 	int i, ik, shift = 0;
 	uint64_t intr_func;
 
+
 	KASSERT(upaid != curcpu()->ci_cpuid);
 
 	/*
@@ -305,6 +309,7 @@ sparc64_send_ipi_sun4u(int upaid, ipifunc_t func, uint64_t arg1, uint64_t arg2)
 void
 sparc64_send_ipi_sun4v(int cpuid, ipifunc_t func, uint64_t arg1, uint64_t arg2)
 {
+printf("%s\n", __FUNCTION__);
 	struct cpu_info *ci = curcpu();
 	int err, i;
 	
@@ -319,13 +324,9 @@ sparc64_send_ipi_sun4v(int cpuid, ipifunc_t func, uint64_t arg1, uint64_t arg2)
 			break;
 		delay(10);
 	}
-#if 1
 	if (err != H_EOK)
 		panic("Unable to send mondo %lx to cpu %d: %d",
 		    (long unsigned int)func, cpuid, err);
-#else
-	while(1);
-#endif	
 }
 
 /*
@@ -490,6 +491,7 @@ smp_tlb_flush_pte(vaddr_t va, struct pmap * pm)
 void
 smp_dcache_flush_page_cpuset(paddr_t pa, sparc64_cpuset_t activecpus)
 {
+  /*printf("%s\n", __FUNCTION__);*/
 	sparc64_multicast_ipi(activecpus, sparc64_ipi_dcache_flush_page_func, pa, dcache_line_size);
 	sp_dcache_flush_page(pa);
 }
