@@ -257,7 +257,7 @@ tsb_invalidate(vaddr_t va, pmap_t pm)
 	bool kpm = (pm == pmap_kernel());
 	int i;
 	int64_t tag;
-
+printf("%s va=%p\n", __FUNCTION__, (void*)va);
 	i = ptelookup_va(va);
 #ifdef MULTIPROCESSOR
 	for (ci = cpus; ci != NULL; ci = ci->ci_next) {
@@ -267,8 +267,10 @@ tsb_invalidate(vaddr_t va, pmap_t pm)
 		ci = curcpu();
 #endif
 		ctx = pm->pm_ctx[ci->ci_index];
+printf("%s ctx=%d\n", __FUNCTION__, ctx);
 		if (kpm || ctx > 0) {
 			tag = TSB_TAG(0, ctx, va);
+printf("%s tag=%lx\n", __FUNCTION__, tag);
 			if (ci->ci_tsb_dmmu[i].tag == tag) {
 				clrx(&ci->ci_tsb_dmmu[i].data);
 			}
@@ -340,7 +342,7 @@ struct {
 #define	REMOVE_STAT(x)	do { remove_stats.x ++; } while (0)
 
 //int	pmapdebug = 0;
-int	pmapdebug = 0 | PDB_CTX_ALLOC | PDB_ACTIVATE | PDB_DESTROY | PDB_REMOVE;
+int	pmapdebug = 0 | PDB_CTX_ALLOC | PDB_ACTIVATE | PDB_DESTROY;
 /* Number of H/W pages stolen for page tables */
 int	pmap_pages_stolen = 0;
 
@@ -1582,6 +1584,9 @@ pmap_copy(struct pmap *dst_pmap, struct pmap *src_pmap, vaddr_t dst_addr, vsize_
 void
 pmap_activate(struct lwp *l)
 {
+
+        DPRINTF(PDB_ACTIVATE, ("pmap_activate(l=%p (%s)):", l, l->l_name));
+
 	struct pmap *pmap = l->l_proc->p_vmspace->vm_map.pmap;
 
 	if (pmap == pmap_kernel()) {
@@ -1606,6 +1611,8 @@ void
 pmap_activate_pmap(struct pmap *pmap)
 {
 
+	DPRINTF(PDB_ACTIVATE, ("pmap_activate_pmap(pm=%p):", pmap));
+
 	if (pmap_ctx(pmap) == 0) {
 		(void) ctx_alloc(pmap);
 	}
@@ -1993,6 +2000,11 @@ pmap_enter(struct pmap *pm, vaddr_t va, paddr_t pa, vm_prot_t prot, u_int flags)
 		KASSERT(pmap_ctx(pm)>=0);
 		i = ptelookup_va(va);
 		tte.tag = TSB_TAG(0, pmap_ctx(pm), va);
+		if (pmap_ctx(pm)) {
+		  printf("%s va=%p\n", __FUNCTION__, (void*)va);
+		  printf("%s tag=%lx\n", __FUNCTION__, tte.tag);
+		  printf("%s data=%lx\n", __FUNCTION__, tte.data);
+		}
 		s = splhigh();
 		if (wasmapped && pmap_is_on_mmu(pm)) {
 			tsb_invalidate(va, pm);
